@@ -551,7 +551,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 0.3.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 0.4.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Title", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -563,10 +563,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.3.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.4.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 0.3.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit GNOME Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 0.4.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Title:"));
 	title_entry = gtk_entry_new();
@@ -646,7 +646,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 0.3.0",
+				 GST_TAG_COMMENT, "Voice 0.4.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
@@ -694,7 +694,7 @@ main (gint argc, gchar **argv)
 			  time_threshold,
 			  on_simple_ready,
 			  CHAMPLAIN_VIEW (view));
-	
+
 	location = gclue_simple_get_location (GCLUE_SIMPLE(simple));
 #endif
 	/* Finish initialising the map view */
